@@ -15,6 +15,8 @@ from glob import glob
 from typing import IO, Any, Collection, Literal, Mapping, Sequence, Union, cast
 from pathlib import Path
 
+import numpy as np
+
 from warnings import warn
 
 from pandas.core.base import DataError
@@ -818,6 +820,10 @@ table, th, td {{
     def sample_wells(self) -> dict[str, list[str]]:
         return self.plate_setup.sample_wells
 
+    @sample_wells.setter
+    def sample_wells(self, new_sample_wells: dict[str, list[str]]):
+        self.plate_setup.sample_wells = new_sample_wells
+
     def __init__(
         self,
         name: str | None = None,
@@ -1899,7 +1905,7 @@ table, th, td {{
 
     def plot_anneal_melt(
         self,
-        samples: str | Sequence[str],
+        samples: str | Sequence[str] | None = None,
         filters: str | FilterSet | Collection[str | FilterSet] | None = None,
         anneal_stages: int | Sequence[int] | None = None,
         melt_stages: int | Sequence[int] | None = None,
@@ -1969,6 +1975,8 @@ table, th, td {{
 
         if isinstance(samples, str):
             samples = [samples]
+        elif samples is None:
+            samples = list(self.plate_setup.sample_wells.keys())
 
         filters = _normalize_filters(filters)
 
@@ -2022,10 +2030,7 @@ table, th, td {{
                 for well in wells:
                     color = next(ax._get_lines.prop_cycler)["color"]
 
-                    if len(wells) > 1:
-                        label = f"{sample} ({well})"
-                    else:
-                        label = sample
+                    label = _gen_label(sample, well, filter, samples, wells, filters)
 
                     anneallines = ax.plot(
                         annealdat.loc[:, (well, "st")],
@@ -2077,7 +2082,7 @@ table, th, td {{
 
     def plot_over_time(
         self,
-        samples: str | Sequence[str],
+        samples: str | Sequence[str] | None = None,
         filters: str | FilterSet | Collection[str | FilterSet] | None = None,
         stages: slice | int | Sequence[int] = slice(None),
         normalization: Normalizer = NormRaw(),
@@ -2156,9 +2161,11 @@ table, th, td {{
 
         if isinstance(samples, str):
             samples = [samples]
+        elif samples is None:
+            samples = list(self.plate_setup.sample_wells.keys())
 
         if isinstance(stages, int):
-            stages = []
+            stages = [stages]
 
         fig = None
 
@@ -2175,7 +2182,7 @@ table, th, td {{
                 fig, ax = plt.subplots(1, 1, **({} if figure_kw is None else figure_kw))
                 ax = [ax]
 
-        elif (not isinstance(ax, Sequence)) or isinstance(ax, plt.Axes):
+        elif (not isinstance(ax, (Sequence, np.ndarray))) or isinstance(ax, plt.Axes):
             ax = [ax]
 
         ax = cast(Sequence[plt.Axes], ax)
@@ -2222,8 +2229,11 @@ table, th, td {{
 
             xlims = ax[0].get_xlim()
 
-            times = reduceddata.loc[(slice(None), stages), ("time", "hours")]
-            tmin, tmax = times.min(), times.max()
+            tmin, tmax = np.inf, 0.0
+            for i, fr in reduceddata.groupby("filter_set", as_index=False):
+                d = fr.loc[i, ("time", "hours")].loc[stages]
+                tmin = min(tmin, d.min())
+                tmax = max(tmax, d.max())
 
             reltemps = self.temperatures.loc[
                 lambda x: (tmin <= x[("time", "hours")])
