@@ -2,7 +2,7 @@ from __future__ import annotations
 from dataclasses import dataclass
 import time
 import typing as tp
-from typing import Union, Dict, Tuple, cast, List, Optional
+from typing import Union, Dict, Tuple, cast, List, Optional, Any
 from nio.client import AsyncClient
 import re
 import asyncio
@@ -14,6 +14,9 @@ from .parser import arglist
 
 from qslib.plate_setup import PlateSetup
 from qslib.qsconnection_async import QSConnectionAsync
+
+from qslib.qsconnection_async import _parse_fd_fn as parse_fd_fn
+
 import logging
 
 from influxdb_client import InfluxDBClient, Point  # , Point, WritePrecision
@@ -35,7 +38,10 @@ class RunState:
     plate_setup: Optional[PlateSetup] = None
 
     async def refresh(self, c: QSConnectionAsync):
-        runmsg = arglist.parseString(await c.run_command("RunProgress?")).asDict()
+        runmsg: dict[str, dict[str, Any]] = cast(
+            dict[str, dict[str, Any]],
+            arglist.parseString(await c.run_command("RunProgress?")).asDict(),
+        )
         print(runmsg)
         self.name = cast(str, runmsg["arglist"]["opts"]["RunTitle"])
         if self.name == "-":
@@ -117,10 +123,10 @@ class State:
         return n
 
 
-def parse_fd_fn(x: str) -> Tuple[str, int, int, int, int]:
-    s = re.search(r"S(\d{2})_C(\d{3})_T(\d{2})_P(\d{4})_M(\d)_X(\d)_filterdata.xml$", x)
-    assert s is not None
-    return (f"x{s[6]}-m{s[5]}", int(s[1]), int(s[2]), int(s[3]), int(s[4]))
+# def parse_fd_fn(x: str) -> Tuple[str, int, int, int, int]:
+#    s = re.search(r"S(\d{2})_C(\d{3})_T(\d{2})_P(\d{4})_M(\d)_X(\d)_filterdata.xml$", x)
+#    assert s is not None
+#    return (f"x{s[6]}-m{s[5]}", int(s[1]), int(s[2]), int(s[3]), int(s[4]))
 
 
 def index_to_filename_ref(i: Tuple[str, int, int, int, int]) -> str:
@@ -400,8 +406,28 @@ class Collector:
 
             log.info(c._protocol.topic_handlers)
 
-            await c._protocol.lostconnection
-            log.error("Lost connection")
+            ok = True
+            while ok:
+                await asyncio.wait((c._protocol.lostconnection,), timeout=60)
+
+                # Have we lost the connection?
+                if c._protocol.lostconnection.done():
+                    log.error("Lost connection.")
+                    ok = False
+
+                # Are we actually fine?
+                if time.time() - c._protocol.last_received <= 60.0:
+                    continue
+
+                # No, we have a sleep timeout.  Send a test command.
+                try:
+                    await asyncio.wait_for(c.run_command("ISTAT?"), 30.0)
+                except TimeoutError:
+                    log.error(
+                        "No data received in 5 minutes and ISTAT? test timed out.  Trying to disconnect."
+                    )
+                    await c.disconnect()
+                    raise TimeoutError
 
     async def reliable_monitor(self):
         log.info("starting reconnectable monitoring")
@@ -426,4 +452,4 @@ class Collector:
                     log.critical(f"giving up, error {e}")
                     restart = False
             log.debug("awaiting retry")
-            await asyncio.sleep(15)
+            await asyncio.sleep(30)
