@@ -13,6 +13,10 @@ import pandas as pd
 import xml.etree.ElementTree as ET
 from .base import AccessLevel
 
+import logging
+
+log = logging.getLogger(__name__)
+
 
 def _gen_auth_response(password: str, challenge_string: str) -> str:
     return hmac.digest(password.encode(), challenge_string.encode(), "md5").hex()
@@ -33,7 +37,7 @@ def _parse_argstring(argstring: str) -> Dict[str, str]:
 
 
 def _parse_fd_fn(x: str) -> Tuple[str, int, int, int, int]:
-    s = re.search(r"S(\d{2})_C(\d{3})_T(\d{2})_P(\d{4})_M(\d)_X(\d)_filterdata.xml$", x)
+    s = re.search(r"S(\d+)_C(\d+)_T(\d+)_P(\d+)_M(\d)_X(\d)_filterdata.xml$", x)
     if s is None:
         raise ValueError
     return (f"x{s[6]}-m{s[5]}", int(s[1]), int(s[2]), int(s[3]), int(s[4]))
@@ -75,6 +79,8 @@ def _validate_command_format(commandstring: str) -> None:
 class QSConnectionAsync:
     """Class for connection to a QuantStudio instrument server, using asyncio"""
 
+    _protocol: QS_IS_Protocol
+
     async def __aenter__(self) -> QSConnectionAsync:
         await self.connect()
         return self
@@ -85,9 +91,20 @@ class QSConnectionAsync:
         await self.disconnect()
 
     async def disconnect(self) -> None:
+        if self._transport.is_closing():
+            return
         await self._protocol.disconnect()
         self._transport.close()
-        self.connected = False
+
+    @property
+    def connected(self) -> bool:
+        if hasattr(self, "_protocol"):
+            if self._protocol.lostconnection.done():
+                return False
+            else:
+                return True
+        else:
+            return False
 
     def __init__(
         self,
@@ -100,7 +117,6 @@ class QSConnectionAsync:
         """Create a connection to a QuantStudio Instrument Server."""
         self.host = host
         self.port = port
-        self.connected = False
         self.password = password
         self._initial_access_level = initial_access_level
         self._authenticate_on_connect = authenticate_on_connect
@@ -149,8 +165,6 @@ class QSConnectionAsync:
         if self._initial_access_level is not None:
             await self.set_access_level(cast(AccessLevel, self._initial_access_level))
 
-        self.connected = True
-
         return resp
 
     async def run_command_to_bytes(self, command: str, just_ack: bool = True) -> bytes:
@@ -274,7 +288,9 @@ class QSConnectionAsync:
     ) -> pd.DataFrame:
         ...
 
-    async def get_all_filterdata(self, run=None, as_list: bool = False) -> pd.DataFrame:
+    async def get_all_filterdata(
+        self, run=None, as_list: bool = False
+    ) -> Union[pd.DataFrame, List[data.FilterDataReading]]:
         if run is None:
             run = await self.get_run_title()
 
